FileRights

Struct FileRights 

pub struct FileRights(/* private fields */);
Used to reduce (but never expand) the capabilities on a file descriptor.

See Also

cap_rights_limit(2).

Example

let mut file = tempfile().unwrap();
FileRights::new()
    .allow(Right::Read)
    .limit(&file).unwrap();

capsicum::enter().unwrap();

let mut buf = vec![0u8; 80];
file.read(&mut buf[..]).unwrap();

let e = file.write(&buf[..]).unwrap_err();
assert_eq!(e.raw_os_error(), Some(libc::ENOTCAPABLE));

Implementations

Source

impl FileRights

pub fn new() -> Self

Initialize a new FileRights which will deny all rights.

pub fn from_file<F: AsFd>(f: &F) -> Result<FileRights>

Retrieve the list of rights currently allowed for the given file.

Example
let file = tempfile().unwrap();
let mut rights = FileRights::new();
rights.allow(Right::Read);

rights.limit(&file).unwrap();
let rights2 = FileRights::from_file(&file).unwrap();
assert_eq!(rights, rights2);
See Also

cap_rights_get(3)

pub fn allow(&mut self, right: Right) -> &mut Self

Add a new Right to the list of allowed rights.

pub fn contains(&self, other: &FileRights) -> bool

Checks if self contains all of the rights present in other.

Example
let mut rights1 = FileRights::new();
rights1.allow(Right::Read);
rights1.allow(Right::Write);
let mut rights2 = FileRights::new();
rights2.allow(Right::Write);
assert!(rights1.contains(&rights2));

let mut rights3 = FileRights::new();
rights3.allow(Right::Read);
rights3.allow(Right::Seek);
assert!(!rights1.contains(&rights3));
pub fn is_set(&self, right: Right) -> bool

Is the given Right set here?

Example

let mut rights = FileRights::new();
rights.allow(Right::Read);
assert!(rights.is_set(Right::Read));
assert!(!rights.is_set(Right::Write));
pub fn is_valid(&self) -> bool

👎Deprecated since 0.4.0:

Unnecessary unless you use FileRights::new

pub fn merge(&mut self, other: &FileRights) -> Result<()>

Add all rights present in other to this structure.

pub fn remove(&mut self, other: &FileRights) -> Result<()>

Remove any rights present in other from this structure, if they are set.

pub fn set(&mut self, raw_rights: Right) -> Result<()>

👎Deprecated since 0.4.0:

use FileRights::allow instead

pub fn clear(&mut self, raw_rights: Right) -> Result<()>

👎Deprecated since 0.4.0:

use FileRights::deny instead

pub fn deny(&mut self, right: Right) -> &mut Self

Remove an allowed Right from the list.